@@ -193,6 +193,8 @@ Lum::Object* DiceEdit::GetContent()
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
+  valuesModel->SetEmptyText(L"(No dice values defined)");
+
   horiz=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
@@ -201,7 +203,7 @@ Lum::Object* DiceEdit::GetContent()
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetHeight(Lum::Base::Size::stdCharHeight,8);
-  table->SetShowHeader(true);
+  table->SetShowHeader(false);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(valuesModel);
