@@ -84,6 +84,8 @@ Lum::Object* DiceSetEdit::GetContent()
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
+  dicesModel->SetEmptyText(L"(No dices defined)");
+
   label=Lum::Label::Create(true,true);
   label->AddLabel(L"Name:",Lum::String::Create(name,true,false));
 
@@ -95,7 +97,7 @@ Lum::Object* DiceSetEdit::GetContent()
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetHeight(Lum::Base::Size::stdCharHeight,6);
-  table->SetShowHeader(true);
+  table->SetShowHeader(false);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(dicesModel);
@@ -107,8 +109,11 @@ Lum::Object* DiceSetEdit::GetContent()
   horiz->AddSpace();
   horiz->Add(Lum::VPanel::Create(false,true)
              ->Add(Lum::Button::Create(_(L"BTN_ADD",L"_Add"),addAction,true,false))
+             ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
+             ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_CLONE",L"_Dupplicate"),cloneAction,true,false))
+             ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
   label->AddLabel(L"Dices:",horiz);
