@@ -20,14 +20,14 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <Lum/Dlg/ActionDialog.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/Dialog.h>
-
 #include "Configuration.h"
 
 class DicesModel : public Lum::Model::StdRefTable<Dice>
@@ -62,7 +62,7 @@ public:
 
 typedef Lum::Base::Reference<DicesModel> DicesModelRef;
 
-class DiceSetEdit : public Lum::Dialog
+class DiceSetEdit : public Lum::Dlg::ActionDialog
 {
 private:
   DiceSet&                           diceSet;
@@ -81,10 +81,14 @@ private:
 
   bool                               result;
 
+private:
+  void EvaluateRights();
+
 public:
   DiceSetEdit(DiceSet& diceSet);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 
